@@ -22,10 +22,6 @@ bind_rows <- function(..., .id = NULL) {
 
   id_vals <- if (is.null(names(res))) 1:length(res) else names(res)
 
-  saf <- default.stringsAsFactors()
-  options(stringsAsFactors = FALSE)
-  on.exit(options(stringsAsFactors = saf))
-
   idx <- 1
   do.call(
     rbind.data.frame,
