@@ -1,7 +1,7 @@
 
 .pkgenv <- new.env(parent=emptyenv())
 
-.onAttach <- function(...) {
+.onLoad <- function(...) {
 
   ctx <- v8()
   ctx$source(system.file("js/bundle.js", package="uaparserjs"))
@@ -9,4 +9,8 @@
 
   assign("ctx", ctx, envir=.pkgenv)
 
-}
\ No newline at end of file
+  cache <- list()
+
+  assign("cache", cache, envir=.pkgenv)
+
+}
